@@ -1,4 +1,4 @@
-/* medit.c -- simple multilingual editor.		-*- coding: euc-jp; -*-
+/* medit.c -- simple multilingual editor.		-*- coding: utf-8; -*-
    Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012
      National Institute of Advanced Industrial Science and Technology (AIST)
      Registration Number H15PRO112
@@ -53,7 +53,7 @@
     for direct use from application programs.
 */
 /***ja
-    @japage m17n-edit ¿ƥȤԽ
+    @japage m17n-edit 多言語テキストの編集
 
     @section m17n-edit-synopsis SYNOPSIS
 
@@ -61,28 +61,28 @@
 
     @section m17n-edit-description DESCRIPTION
 
-    FILE 򥦥ɥɽ桼ԽǤ褦ˤ롣
+    FILE をウィンドウに表示し、ユーザが編集できるようにする。
 
-    XT-OPTIONs  Xt ɸΰǤ롣 (e.g. -fn, -fg). 
+    XT-OPTIONs は Xt の標準の引数である。 (e.g. -fn, -fg). 
 
-    ʲΥץѤǤ롣 
+    以下のオプションが利用できる。 
 
     <ul>
 
     <li> --version
 
-    Сֹɽ롣 
+    バージョン番号を表示する。 
 
     <li> -h, --help
 
-    Υåɽ롣 
+    このメッセージを表示する。 
 
     </ul>
 
-    Υץ m17n GUI API λȤ򼨤ΤǤ롣m17n-edit
-    ľ GUI API ȤäƤ뤬 API ϼ˥ġ륭åȥ饤֥
-    XOM (X Output Method) μѤǤꡢץꥱץ
-    फľܤѤտޤƤʤ
+    このプログラムは m17n GUI API の使い方を示すものである。m17n-edit
+    は直接 GUI API を使っているが、この API は主にツールキットライブラ
+    リやXOM (X Output Method) の実装用であり、アプリケーションプログラ
+    ムからの直接の利用を意図していない。
 */
 
 #ifndef FOR_DOXYGEN
