@@ -1,5 +1,5 @@
-/* mview.c -- File viewer				-*- coding: euc-jp; -*-
-   Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008
+/* mview.c -- File viewer				-*- coding: utf-8; -*-
+   Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012
      National Institute of Advanced Industrial Science and Technology (AIST)
      Registration Number H15PRO112
 
@@ -18,7 +18,7 @@
    You should have received a copy of the GNU Lesser General Public
    License along with the m17n library; if not, write to the Free
    Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   02111-1307, USA.  */
+   Boston, MA 02110-1301 USA.  */
 
 /***en
     @enpage m17n-view view file
@@ -59,7 +59,7 @@
     </ul>
 */
 /***ja
-    @japage m17n-view ե򸫤
+    @japage m17n-view ファイルを見る
 
     @section m17n-view-synopsis SYNOPSIS
 
@@ -67,33 +67,33 @@
 
     @section m17n-view-description DESCRIPTION
 
-    FILE 򥦥ɥɽ롣 
+    FILE をウィンドウに表示する。 
 
-    FILE ά줿ϡɸϤȤ롣 
+    FILE が省略された場合は、標準入力からとる。 
 
-    XT-OPTIONs  Xt ɸΰǤ롣 (e.g. -fn, -fg). 
+    XT-OPTIONs は Xt の標準の引数である。 (e.g. -fn, -fg). 
 
-    ʲΥץѤǤ롣 
+    以下のオプションが利用できる。 
 
     <ul>
 
     <li> -e ENCODING
 
-    ENCODING  FILE ΥɷϤǤ롣(ǥեȤ UTF-8) 
+    ENCODING は FILE のコード系である。(デフォルトは UTF-8) 
 
     <li> -s FONTSIZE
 
-    FONTSIZE ϥեȤ礭ݥñ̤ǼΤǤ롣ά 
-    줿ϡX Υ꥽줿ǥեȥեȤ礭 
-    ʤ롣
+    FONTSIZE はフォントの大きさをポイント単位で示したものである。省略 
+    された場合は、X のリソースで定義されたデフォルトフォントの大きさと 
+    なる。
 
     <li> --version
 
-    Сֹɽ롣
+    バージョン番号を表示する。
 
     <li> -h, --help
 
-   Υåɽ롣 
+   このメッセージを表示する。 
 
     </ul>
 */
@@ -290,7 +290,7 @@ main (int argc, char **argv)
       else if (! strcmp (argv[i], "--version"))
 	{
 	  printf ("m17n-view (m17n library) %s\n", M17NLIB_VERSION_NAME);
-	  printf ("Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008 AIST, JAPAN\n");
+	  printf ("Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012 AIST, JAPAN\n");
 	  exit (0);
 	}
       else if (! strcmp (argv[i], "-e"))
