@@ -1,5 +1,5 @@
 /* input-gui.c -- gui-based input method module.
-   Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010
+   Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012
      National Institute of Advanced Industrial Science and Technology (AIST)
      Registration Number H15PRO112
 
@@ -18,7 +18,7 @@
    You should have received a copy of the GNU Lesser General Public
    License along with the m17n library; if not, write to the Free
    Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   02111-1307, USA.  */
+   Boston, MA 02110-1301 USA.  */
 
 /***en
     @addtogroup m17nInputMethodWin
@@ -37,18 +37,18 @@
 
 /***ja
     @addtogroup m17nInputMethodWin
-    @brief ɥƥϥ᥽åɤΥݡ.
+    @brief ウィンドウシステム上の入力メソッドのサポート.
 
-    ϥɥ饤 @c minput_gui_driver ϡ
-    ɥƥѤϥ᥽åѤΥɥ饤ФǤ롣
-    Υɥ饤ФϥݥåȤ preedit ƥȤ status 
-    ƥȤɽ롣ܺ٤ˤĤƤ @c minput_gui_driver 򻲾ȤΤȡ
+    入力ドライバ @c minput_gui_driver は、
+    ウィンドウシステム上で用いられる内部入力メソッド用のドライバである。
+    このドライバは入力スポットに preedit テキストと status 
+    テキストを表示する。詳細については @c minput_gui_driver の説明を参照のこと。
 
-    m17n-X 饤֥ϡ@c Mxim ȸ̾ĳϥ᥽åɤ󶡤Ƥ롣 
-    XIM (X Input Method) Хå饦ɤϥ󥸥ȤѤ롣ܥ
-    @c Mxim  @c Minput_driver ȤץѥƥäƤꡢͤϥɥ饤 
-    @c minput_xim_driver ؤΥݥ󥿤Ǥ롣 ܺ٤ˤĤƤ 
-    @c minput_xim_driver 򻲾ȤΤȡ  */
+    m17n-X ライブラリは、@c Mxim と言う名前を持つ外部入力メソッドを提供している。これは 
+    XIM (X Input Method) をバックグラウンドの入力エンジンとして利用する。シンボル
+    @c Mxim は @c Minput_driver というプロパティを持っており、その値は入力ドライバ 
+    @c minput_xim_driver へのポインタである。 詳細については 
+    @c minput_xim_driver の説明を参照のこと。  */
 
 /*=*/
 
@@ -151,7 +151,6 @@ static int
 win_filter (MInputContext *ic, MSymbol key, void *arg)
 {
   MInputGUIContextInfo *win_ic_info = (MInputGUIContextInfo *) ic->info;
-  MInputContextInfo *ic_info = (MInputContextInfo *) win_ic_info->ic_info;
   int ret;
 
   if (! ic
@@ -164,8 +163,9 @@ win_filter (MInputContext *ic, MSymbol key, void *arg)
       if (key == Mnil)
 	return 1;
     }
-  ic->info = ic_info;
+  ic->info = win_ic_info->ic_info;
   ret = (*minput_default_driver.filter) (ic, key, arg);
+  win_ic_info->ic_info = (MInputContextInfo *) ic->info;
   ic->info = win_ic_info;
   return ret;
 }
@@ -615,33 +615,33 @@ minput__win_fini ()
     same one as that of the function minput_filter (). */
 
 /***ja
-    @brief ɥƥϥ᥽åϥɥ饤.
+    @brief ウィンドウシステムの内部入力メソッド用入力ドライバ.
 
-    ϥɥ饤 @c minput_gui_driver
-    ϡɥƥѤϥ᥽åѥɥ饤ФǤ롣
+    入力ドライバ @c minput_gui_driver
+    は、ウィンドウシステム上で用いられる入力メソッド用ドライバである。
 
-    Υɥ饤Фϡؿ minput_set_spot () ˤäꤵ줿ϥݥåȤ
-    preedit ƥѤΥ֥ɥ status 
-    ƥѤΥ֥ɥꡢ줾ɽ롣
+    このドライバは、関数 minput_set_spot () によって設定された入力スポットに
+    preedit テキスト用のサブウィンドウと status 
+    テキスト用のサブウィンドウを作り、それぞれを表示する。
 
-    ޥ M17N_INIT () ѿ @c minput_driver 
-    򤳤Υɥ饤ФؤΥݥ󥿤ꤷƤϥ᥽åɤΥɥ饤ФȤ褦ˤ롣
+    マクロ M17N_INIT () は変数 @c minput_driver 
+    をこのドライバへのポインタに設定し、全ての内部入力メソッドがこのドライバを使うようにする。
 
-    äơ@c minput_driver ǥեͤΤޤޤǤСminput_ 
-    ǻϤޤ̾ĴؿΰΤɥ饤а¸ΤΤϰʲΤ褦ˤʤ롣
+    したがって、@c minput_driver がデフォルト値のままであれば、minput_ 
+    で始まる名前を持つ関数の引数のうちドライバ依存のものは以下のようになる。
 
-    ؿ minput_open_im () ΰ $ARG ̵뤵롣
+    関数 minput_open_im () の引数 $ARG は無視される。
 
-    ؿ minput_create_ic () ΰ $ARG Ϲ¤ @c MInputGUIArgIC 
-    ؤΥݥ󥿤ǤʤƤϤʤʤܺ٤ˤĤƤ @c MInputGUIArgIC 
-    򻲾ȤΤȡ
+    関数 minput_create_ic () の引数 $ARG は構造体 @c MInputGUIArgIC 
+    へのポインタでなくてはならない。詳細については @c MInputGUIArgIC 
+    の説明を参照のこと。
 
-    ؿ minput_filter () ΰ $ARG  @c Mnil ξ硢 $ARG  @c
-    XEvent Υ֥ȤؤΥݥ󥿤ǤʤƤϤʤʤξ 
-    $KEY  $ARG 롣
+    関数 minput_filter () の引数 $ARG が @c Mnil の場合、 $ARG は @c
+    XEvent 型のオブジェクトへのポインタでなくてはならない。この場合 
+    $KEY は $ARG から生成される。
 
-    ؿ minput_lookup () ΰ $ARG ϴؿ minput_filter () ΰ 
-    $ARG ƱǤʤƤϤʤʤ */
+    関数 minput_lookup () の引数 $ARG は関数 minput_filter () の引数 
+    $ARG と同じでなくてはならない。 */
 
 MInputDriver minput_gui_driver;
 
@@ -653,10 +653,10 @@ MInputDriver minput_gui_driver;
     The variable Mxim is a symbol of name "xim".  It is a name of the
     input method driver #minput_xim_driver.  */ 
 /***ja
-    @brief "xim"̾Ȥƻĥܥ .
+    @brief "xim"を名前として持つシンボル .
 
-    ѿ Mxim "xim"̾ȤƻĥܥǤ롣"xim" 
-    ϥ᥽åɥɥ饤 #minput_xim_driver ̾Ǥ롣  */ 
+    変数 Mxim は"xim"を名前として持つシンボルである。"xim" 
+    は入力メソッドドライバ #minput_xim_driver の名前である。  */ 
 
 MSymbol Mxim;
 
@@ -693,32 +693,32 @@ MSymbol Mxim;
     At last, a symbol who has the name is returned.  */
 
 /***ja
-    @brief ٥ȤϥѴ.
+    @brief イベントを入力キーに変換する.
 
-    ؿ minput_event_to_key () ϡ$FRAME Υ٥ $EVENT 
-    бϥ֤ǤΡбפϥɥƥ˰¸롣
+    関数 minput_event_to_key () は、$FRAME のイベント $EVENT 
+    に対応する入力キーを返す。ここでの「対応」はウィンドウシステムに依存する。
 
-    m17n-X 饤֥ξˤϡ$EVENT  ¤ @c XKeyEvent 
-    ؤΥݥ󥿤ǤꡢΤ褦˽롣
+    m17n-X ライブラリの場合には、$EVENT は 構造体 @c XKeyEvent 
+    へのポインタであり、次のように処理される。
 
-    ޤؿ @c XKeysymToString ˤäơ$EVENT  keysym 
-    ̾ǰʲѹä롣
+    まず、関数 @c XKeysymToString によって、$EVENT の keysym 
+    名を取得し、次いで以下の変更を加える。
 
-    ̾ "a" .. "z" Τ줫Ǥä $EVENT  Shift 
-    ǥեС̾Ϥ줾 "A" .. "Z" Ѵ졢Shift 
-    ǥեϼ롣
+    名前が "a" .. "z" のいずれかであって $EVENT に Shift 
+    モディファイアがあれば、名前はそれぞれ "A" .. "Z" に変換され、Shift 
+    モディファイアは取り除かれる。
 
-    ̾ХĹ $EVENT  Control ǥեС̾
-    0x1F Ȥӥåñ̤ and 黻Control ǥեϼ롣
+    名前が１バイト長で $EVENT に Control モディファイアがあれば、名前と
+    0x1F とをビット単位で and 演算し、Control モディファイアは取り除かれる。
 
-    Ǥ $EVENT ˤޤǥեС̾ˤ줾
+    それでも $EVENT にまだモディファイアがあれば、名前の前にそれぞれ
     "S-" (Shift), "C-" (Control), "M-" (Meta), "A-" (Alt), , "G-" (AltGr),
-    "s-" (Super), "H-" (Hyper)ν֤դ
+    "s-" (Super), "H-" (Hyper)がこの順番で付く。
     
-    ȤСkeysym ̾ "a" ǥ٥Ȥ Shift, Meta, and Hyper 
-    ǥեƤС̾ "M-H-A" Ǥ롣
+    たとえば、keysym 名が "a" でイベントが Shift, Meta, and Hyper 
+    モディファイアを持てば、得られる名前は "M-H-A" である。
 
-    Ǹˤ̾ĥܥ֤*/
+    最後にその名前を持つシンボルを返す。*/
 
 
 MSymbol
@@ -759,6 +759,6 @@ minput_event_to_key (MFrame *frame, void *event)
 
 /*
   Local Variables:
-  coding: euc-japan
+  coding: utf-8
   End:
 */
