@@ -1,5 +1,5 @@
 /* m17n-gui.h -- header file for the GUI API of the m17n library.
-   Copyright (C) 2003, 2004
+   Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012
      National Institute of Advanced Industrial Science and Technology (AIST)
      Registration Number H15PRO112
 
@@ -18,7 +18,7 @@
    You should have received a copy of the GNU Lesser General Public
    License along with the m17n library; if not, write to the Free
    Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   02111-1307, USA.  */
+   Boston, MA 02110-1301 USA.  */
 
 #ifndef _M17N_GUI_H_
 #define _M17N_GUI_H_
@@ -48,12 +48,12 @@ extern void m17n_fini_win (void);
 /***en @defgroup m17nGUI GUI API
     @brief API provided by libm17n-gui.so */
 /***ja @defgroup m17nGUI GUI API
-    @brief libm17n-gui.so 󶡤 API */
+    @brief libm17n-gui.so が提供する API */
 /*=*/
 
 /*** @ingroup m17nGUI */
 /***en @defgroup m17nFrame Frame */
-/***ja @defgroup m17nFrame ե졼 */
+/***ja @defgroup m17nFrame フレーム */
 /*=*/
 
 /*** @ingroup m17nFrame */
@@ -70,15 +70,15 @@ extern void m17n_fini_win (void);
     @e display and @e screen in the X Window System.  */
 
 /***ja
-    @brief ե졼η.
+    @brief フレームの型宣言.
 
-    #MFrame ϡ@e ե졼 ֥ѤηǤ롣
-    ġΥե졼ϡ줬бʪŪɽϥǥХγƼݻ롣
+    #MFrame は、@e フレーム オブジェクト用の型である。
+    個々のフレームは、それが対応する物理的な表示／入力デバイスの各種情報を保持する。
 
-    #MFrame ¤ϡץꥱץफϸʤ
-    ޤƤϻѤ륦ɥƥ˰¸롣ޤ m17n-X 
-    饤֥ˤե졼ϡX ɥ @e display  @e screen 
-    ˴ؤġ      */
+    #MFrame 型の内部構造は、アプリケーションプログラムからは見えない。
+    またその内容は使用するウィンドウシステムに依存する。また m17n-X 
+    ライブラリにおけるフレームは、X ウィンドウの @e display と @e screen 
+    に関する情報を持つ。      */
 
 typedef struct MFrame MFrame;
 
@@ -108,7 +108,7 @@ extern void *mframe_get_prop (MFrame *frame, MSymbol key);
 
 /*** @ingroup m17nGUI  */
 /***en @defgroup m17nFont Font */
-/***ja @defgroup m17nFont ե */
+/***ja @defgroup m17nFont フォント */
 /*=*/
 
 /*** @ingroup m17nFont */
@@ -126,15 +126,15 @@ extern void *mframe_get_prop (MFrame *frame, MSymbol key);
     The internal structure is concealed from an application program.  */
 
 /***ja
-    @brief եȤη.
+    @brief フォントの型宣言.
 
-    #MFont ϥեȻѤι¤ΤǤꡢեȤΥץѥƥǤ
+    #MFont 型はフォント指定用の構造体であり、フォントのプロパティである
     foundry, family, weight, style, stretch, adstyle, registry,
-    size, resolution ˴ؤޤࡣ
+    size, resolution に関する情報を含む。
 
-    ι¤ΤϥեȥåΥեȤꤹݤȡѲǽʥƥեȤξǼݤξѤ롣
+    この構造体はフォントセット内のフォントを指定する際と、使用可能なシステムフォントの情報を格納する際の両方に用いられる。
 
-    ¤ϥץꥱץफϸʤ  */
+    内部構造はアプリケーションプログラムからは見えない。  */
 
 /***
     @seealso
@@ -200,17 +200,17 @@ extern int mfont_set_encoding (MFont *font,
     font not greater than the #Msize property of $SPEC.  */
 
 /***ja
-    @brief եȤõ.
+    @brief フォントを探す.
 
-    ؿ mfont_find () ϡե졼 $FRAME ǥե $SPEC 
-    ˤäȤפѲǽʥեȤؤΥݥ󥿤֤  
+    関数 mfont_find () は、フレーム $FRAME 上でフォント定義 $SPEC 
+    にもっとも合致する使用可能なフォントへのポインタを返す。  
 
-    $SCORE  NULL Ǥ뤫ĤäեȤ $SPEC 
-    ˤɤۤɹäƤ뤫򼨤¸ؤΥݥ󥿤Ǥ롣
-    ۤɤäƤ뤳Ȥ̣롣
+    $SCORE は NULL であるか、見つかったフォントが $SPEC 
+    にどれほど合っているかを示すスコアを保存する場所へのポインタである。
+    スコアが小さいほど良く合っていることを意味する。
 
-    $LIMITED_SIZE  0 ǤʤС$SPEC Υץѥƥ #Msize 
-    礭ʤեȤõ롣
+    $LIMITED_SIZE が 0 でなければ、$SPEC のプロパティ #Msize 
+    より大きくないフォントだけが探される。
 */
 
 extern MFont *mfont_find (MFrame *frame, MFont *spec,
@@ -243,7 +243,7 @@ extern int mfont_close (MFont *font);
 
 /*** @ingroup m17nGUI  */
 /***en @defgroup m17nFontset Fontset */
-/***ja @defgroup m17nFontset եȥå */
+/***ja @defgroup m17nFontset フォントセット */
 /*=*/
 /*** @addtogroup m17nFontset
      @{   */
@@ -267,9 +267,8 @@ extern MPlist *mfontset_lookup (MFontset *fontset, MSymbol script,
 
 /*** @ingroup m17nGUI */
 /***en @defgroup m17nFace Face */
-/***ja @defgroup m17nFace ե */
+/***ja @defgroup m17nFace フェース */
 /*=*/
-
 /*** @ingroup m17nFace */
 /***en
     @brief Type of faces.
@@ -278,10 +277,10 @@ extern MPlist *mfontset_lookup (MFontset *fontset, MSymbol script,
     structure is concealed from an application program.  */
 
 /***ja
-    @brief եη.
+    @brief フェースの型宣言.
 
-    #MFace ϥե֥ȤΤι¤ΤǤ롣
-    ¤ϥץꥱץफϸʤ  */
+    #MFace 型はフェースオブジェクトのための構造体である。
+    内部構造はアプリケーションプログラムからは見えない。  */
 
 typedef struct MFace MFace;
 /*=*/
@@ -345,16 +344,16 @@ extern MFace *mface_from_font (MFont *font);
     property of a face.  The value of the property must be a pointer
     to an object of this type.  */
 /***ja
-    @brief եοʿѷ.
+    @brief フェースの水平線指定用型宣言.
 
-    #MFaceHLineProp ϥե #Mhline 
-    ץѥƥξܺ٤ꤹ뷿Ǥ롣ΥץѥƥͤϤηΥ֥ȤǤʤƤϤʤʤ
+    #MFaceHLineProp はフェースの #Mhline 
+    プロパティの詳細を指定する型である。このプロパティの値はこの型のオブジェクトでなくてはならない。
       */
 
 typedef struct
 {
   /***en Type of the horizontal line.  */
-  /***ja ʿΥ.  */
+  /***ja 水平線のタイプ.  */
   enum MFaceHLineType
     {
       MFACE_HLINE_BOTTOM,      
@@ -365,12 +364,12 @@ typedef struct
     } type;
 
   /***en Width of the line in pixels.  */
-  /***ja ʥԥñ̡.  */
+  /***ja 線幅（ピクセル単位）.  */
   unsigned width;
 
   /***en Color of the line.  If the value is Mnil, foreground color of
       a merged face is used.  */
-  /***ja ο.  Mnil ʤС礷եʿȤ롣  */
+  /***ja 線の色.  Mnil ならば、統合したフェースの前景色が使われる。  */
   
   MSymbol color;
 } MFaceHLineProp;
@@ -384,27 +383,33 @@ typedef struct
     of a face.  The value of the property must be a pointer to an
     object of this type.  */
 /***ja
-    @brief եΰϤȻѷ.
+    @brief フェースの囲み枠指定用型宣言.
 
-    #MFaceBoxProp ϥե #Mbox ץѥƥξܺ٤ꤹ뷿Ǥ롣
-    ΥץѥƥͤϤηΥ֥ȤؤΥݥ󥿤ǤʤƤϤʤʤ
+    #MFaceBoxProp はフェースの #Mbox プロパティの詳細を指定する型である。
+    このプロパティの値はこの型のオブジェクトへのポインタでなくてはならない。
       */
 
 typedef struct
 {
   /***en Width of the box line in pixels.  */
-  /***ja ʥԥñ̡.  */
+  /***ja 線幅（ピクセル単位）.  */
   unsigned width;
 
+  /* @{ */
+  /*** Colors of borders.  */
   MSymbol color_top;
   MSymbol color_bottom;
   MSymbol color_left;
   MSymbol color_right;
+  /* @} */
 
+  /* @{ */
+  /*** Margins  */
   unsigned inner_hmargin;
   unsigned inner_vmargin;
   unsigned outer_hmargin;
   unsigned outer_vmargin;
+  /* @} */
 
 } MFaceBoxProp;
 /*=*/
@@ -415,9 +420,9 @@ typedef struct
 
     #MFaceHookFunc is a type of a hook function of a face.  */
 /***ja
-    @brief եΥեåؿη.
+    @brief フェースのフック関数の型宣言.
 
-    #MFaceHookFunc ϥեΥեåؿηǤ롣*/
+    #MFaceHookFunc はフェースのフック関数の型である。*/
 typedef void (*MFaceHookFunc) (MFace *face, void *arg, void *info);
 /*=*/
 
@@ -436,7 +441,7 @@ extern void mface_update (MFrame *frame, MFace *face);
 
 /*** @ingroup m17nGUI */
 /***en @defgroup m17nDraw Drawing */
-/***ja @defgroup m17nDraw ɽ */
+/***ja @defgroup m17nDraw 表示 */
 /*=*/
 
 /*** @ingroup m17nDraw */
@@ -450,12 +455,12 @@ extern void mface_update (MFrame *frame, MFace *face);
     that uses the m17n-X library must coerce the type @c Drawable to
     this type.  */
 /***ja 
-    @brief ɥƥ˰¸롢ɥη.
+    @brief ウィンドウシステムに依存する、ウィンドウの型宣言.
 
-    #MDrawWindow ϥɥʤĤǥ꡼Υߥ˥奢ȤƯΰѤηǤ롣
+    #MDrawWindow はウィンドウ、すなわち幾つかの点でスクリーンのミニチュアとして働く矩形領域用の型である。
 
-    ºݤ˲ؤϥɥƥ˰¸롣 m17n X 
-    饤֥Ѥץ @c Drawable 򤳤ηѴʤƤϤʤʤ */
+    実際に何を指すかはウィンドウシステムに依存する。 m17n X 
+    ライブラリを利用するプログラムは @c Drawable 型をこの型に変換しなくてはならない。 */
 
 typedef void *MDrawWindow;
 /*=*/
@@ -471,12 +476,12 @@ typedef void *MDrawWindow;
     that uses the m17n-X library must coerce the type @c Region to
     this type.  */
 /***ja
-    @brief ɥƥ˰¸롢ΰη.
+    @brief ウィンドウシステムに依存する、領域の型宣言.
 
-    #MDrawRegion ΰ衢ʤ꡼ǤդΥԥνŵŪˤ϶ΰѤηǤ롣
+    #MDrawRegion は領域、すなわちスクリーン上の任意のピクセルの集合（典型的には矩形領域）用の型である。
 
-    ºݤ˲ؤϥɥƥ˰¸롣 m17n X 
-    饤֥Ѥץ @c Region 򤳤ηѴʤƤϤʤʤ  */
+    実際に何を指すかはウィンドウシステムに依存する。 m17n X 
+    ライブラリを利用するプログラムは @c Region 型をこの型に変換しなくてはならない。  */
 
 typedef void *MDrawRegion;
 /*=*/
@@ -488,9 +493,9 @@ typedef void *MDrawRegion;
     The type #MDrawControl is the structure that controls how to draw
     an M-text.  */
 /***ja
-    @brief ƥɽη.
+    @brief テキスト表示制御の型宣言.
 
-    #MDrawControl ϡM-text ɤɽ뤫椹빽¤ΤǤ롣
+    #MDrawControl 型は、M-text をどう表示するかを制御する構造体である。
       */
 
 
@@ -499,15 +504,15 @@ typedef struct
   /***en If nonzero, draw an M-text as image, i.e. with background
       filled with background colors of faces put on the M-text.
       Otherwise, the background is not changed.  */
-  /***ja 0 ǤʤС M-text Ȥơʤطʤ M-text 
-      ΥեǻꤵƤطʿɽ롣ǤʤطʤѤʤ  */
+  /***ja 0 でなければ、 M-text を画像として、すなわち背景を M-text 
+      のフェースで指定されている背景色で埋めて表示する。そうでなければ背景は変わらない。  */
   unsigned as_image : 1;
 
   /***en If nonzero and the first glyph of each line has negative
       lbearing, shift glyphs horizontally to right so that no pixel is
       drawn to the left of the specified position.  */
-  /***ja 0 ǤʤƹԤκǽΥդ lbearing 
-      ʤСդʿ˱ˤ餷ơꤷ֤꺸˥ԥ뤬ʤ褦ˤ롣  */
+  /***ja 0 でなく、各行の最初のグリフの lbearing 
+      が負ならば、グリフを水平に右にずらして、指定した位置より左にピクセルが描かれないようにする。  */
   unsigned align_head : 1;
 
   /***en If nonzero, draw an M-text two-dimensionally, i.e., newlines
@@ -515,68 +520,70 @@ typedef struct
       the next line.  If \<format\> is non-NULL, and the function
       returns nonzero line width, a line longer than that width is
       also broken.  */
-  /***ja 0 ǤʤСM-text 򣲼Ūˡʤ M-text  
-      newline ǲԤ³ʸϼιԤɽ롣⤷ \<format\>  
-      NULL Ǥʤδؿ 0 Ǥʤ֤СĹԤԤ롣  */
+  /***ja 0 でなければ、M-text を２次元的に、すなわち M-text 中の 
+      newline で改行し、続く文字は次の行に表示する。もし \<format\> が 
+      NULL でなく、その関数が 0 でない行幅を返せば、その幅より長い行も改行される。  */
   unsigned two_dimensional : 1;
 
   /***en If nonzero, draw an M-text to the right of a specified
       position.  */
-  /***ja 0 ǤʤСM-text ꤷ֤αɽ롣  */
+  /***ja 0 でなければ、M-text を指定した位置の右に表示する。  */
   unsigned orientation_reversed : 1;
 
   /***en If nonzero, reorder glyphs correctly for bidi text.  */ 
-  /***ja 0 ʤСbidi ƥѤ˥դ󤹤롣  */
+  /***ja 0 なければ、bidi テキスト用にグリフを正しく整列する。  */
   unsigned enable_bidi : 1;
 
   /***en If nonzero, don't draw characters whose general category (in
       Unicode) is Cf (Other, format).  */
-  /***ja 0 ǤʤС˥ɤ֤̥ƥ꤬ Cf (Other,
-      format) Ǥʸɽʤ  */
+  /***ja 0 でなければ、ユニコードに置ける一般カテゴリが Cf (Other,
+      format) である文字を表示しない。  */
   unsigned ignore_formatting_char : 1;
 
   /***en If nonzero, draw glyphs suitable for a terminal.  Not yet
       implemented.  */
-  /***ja 0 ǤʤСüѤΥդɽ롣̤  */
+  /***ja 0 でなければ、端末用のグリフを表示する。未実装。  */
   unsigned fixed_width : 1;
 
   /***en If nonzero, draw glyphs with anti-aliasing if a backend font
       driver supports it.  */
-  /***ja 0 ǤʤСꥢǥդɽ롣
-      ʥХåɤΥեȥɥ饤ФꥢǽľΤߡ */
+  /***ja 0 でなければ、アンチエーリアスでグリフを表示する。
+      （バックエンドのフォントドライバがアンチエーリアス機能を持つ場合のみ。） */
   unsigned anti_alias : 1;
 
   /***en If nonzero, disable the adjustment of glyph positions to
       avoid horizontal overlapping at font boundary.  */
-  /***ja 0 ǤʤСեȶǤοʿΥդνŤʤ򤱤뤿Υհ֤Ĵ̵ˤ롣  */
+  /***ja 0 でなければ、フォント境界での水平方向のグリフの重なりを避けるためのグリフ位置の調整を無効にする。  */
   unsigned disable_overlapping_adjustment : 1;
 
-  /***en If nonzero, the values are minimum line ascent and descent
-      pixels.  */
-  /***ja 0 ǤʤСͤϹԤ ascent  descent κǾͤ򼨤  */
+  /***en If nonzero, the values are minimum line ascent pixels.  */
+  /***ja 0 でなければ、値は行の ascent の最小値を示す。  */
   unsigned int min_line_ascent;
+  /***en If nonzero, the values are minimum line descent pixels.  */
+  /***ja 0 でなければ、値は行の descent の最小値を示す。  */
   unsigned int min_line_descent;
 
-  /***en If nonzero, the values are maximum line ascent and descent
-      pixels.  */
-  /***ja 0 ǤʤСͤϹԤ ascent  descent κͤ򼨤  */
+  /***en If nonzero, the values are maximum line ascent pixels.  */
+  /***ja 0 でなければ、値は行の ascent の最大値を示す。  */
   unsigned int max_line_ascent;
+  /***en If nonzero, the values are maximum line descent pixels.  */
+  /***ja 0 でなければ、値は行の descent の最大値を示す。  */
   unsigned int max_line_descent;
 
   /***en If nonzero, the value specifies how many pixels each line can
       occupy on the display.  The value zero means that there is no
       limit.  It is ignored if \<format\> is non-NULL.  */
-  /***ja 0 ǤʤСͤϤΥǥץ쥤ǳƹԤ뤳ȤΤǤԥ򼨤
-      0 ϸꤵʤȤ̣롣\<format\>  NULL Ǥʤ̵뤵롣   */
+  /***ja 0 でなければ、値はこのディスプレイ上で各行が占めることのできるピクセル数を示す。
+      0 は限定されないことを意味する。\<format\> が NULL でなければ無視される。   */
   unsigned int max_line_width;
 
   /***en If nonzero, the value specifies the distance between tab
       stops in columns (the width of one column is the width of a
       space in the default font of the frame).  The value zero means
       8.  */
-  /***ja 0 ǤʤСͤϥ֥ȥå״֤εΥ򥳥ñ
-      ʥϥե졼ΥǥեȥեȤˤʸǤˤǼ 
-      0  8 ̣롣 */
+  /***ja 0 でなければ、値はタブストップ間の距離をコラム単位
+      （コラムはフレームのデフォルトフォントにおける空白文字の幅である）で示す。 
+      0 は 8 を意味する。 */
   unsigned int tab_width;
 
   /***en If non-NULL, the value is a function that calculates the
@@ -599,21 +606,21 @@ typedef struct
       because of the width limit.
 
       This has an effect only when \<two_dimensional\> is nonzero.  */
-  /***ja 0 ǤʤСͤϴؿǤꡢδؿϹֹ LINE Ⱥɸ Y 
-      ˴ŤƳƹԤΥǥȤȺ׻줾INDENT 
-      WIDTH ǻؤ¸롣
+  /***ja 0 でなければ、値は関数であり、その関数は行番号 LINE と座標 Y 
+      に基づいて各行のインデントと最大幅を計算し、それぞれをINDENT と
+      WIDTH で指される場所に保存する。
 
-      ǥȤϡƹԤκǽΥդ򱦡ʥ 
-      \<orientation_reversed\>  0 
-      λˤ뤤Ϻʤʳλˤ˲ԥ뤺餹ꤹ롣ͤʤеˤ餹
+      インデントは、各行の最初のグリフを右（メンバ 
+      \<orientation_reversed\> が 0 
+      の時）あるいは左（それ以外の時）に何ピクセルずらすかを指定する。値が負ならば逆方向にずらす。
 
-      ϡƹԤǥץ쥤뤳ȤΤǤԥκͤǤ롣ͤ
-      0 ξ¤ʤȤ̣롣
+      最大幅は、各行がディスプレイ上で占めることのできるピクセル数の最大値である。値が
+      0 の場合は制限を受けないことを意味する。
 
-      LINE  Y ϲʸˤäƹԤޤäݤˤ 0 
-      ˥ꥻåȤ졢ĹԤ¤ˤäƲԤ뤿Ӥ 1 䤵롣
+      LINE と Y は改行文字によって行が改まった際には 0 
+      にリセットされ、長い行が最大幅の制限によって改行されるたびに 1 増やされる。
 
-       \<two_dimensional\>  0 ǤʤˤΤͭǤ롣  */
+      これは \<two_dimensional\> が 0 でない場合にのみ有効である。  */
   void (*format) (int line, int y, int *indent, int *width);
 
   /***en If non-NULL, the value is a function that calculates a line
@@ -631,18 +638,20 @@ typedef struct
 
       The mdraw_default_line_break () function is useful for such a
       script that uses SPACE as a word separator.  */
-  /***ja NULL ǤʤСͤϹԤ˼ޤʤ˹Ԥ֤׻ؿǤ롣
-      POS Ϻ˼ޤǸʸμʸΰ֤Ǥ롣FROM
-      ϹԤκǽʸΰ֡TO 
-      ϺꤵƤʤФιԤɽǸʸΰ֤Ǥ롣LINE 
-       Y  \<format\> ΰƱͤǤ롣
+  /***ja NULL でなければ、値は行が最大幅中に収まらない場合に行を改める位置を計算する関数である。
+      POS は最大幅に収まる最後の文字の次の文字の位置である。FROM
+      は行の最初の文字の位置、TO 
+      は最大幅が指定されていなければその行に表示される最後の文字の位置である。LINE 
+      と Y は \<format\> の引数と同様である。
 
-      δؿϹԤʸ֤֤ʤƤϤʤʤޤ MT ѹƤϤʤʤ
+      この関数は行を改める文字位置を返さなくてはならない。また MT を変更してはならない。
 
-      ؿ mdraw_default_line_break ()
-      ϡζڤȤѤ륹ץѤȤͭѤǤ롣  */
+      関数 mdraw_default_line_break ()
+      は、空白を語の区切りとして用いるスクリプト用として有用である。  */
   int (*line_break) (MText *mt, int pos, int from, int to, int line, int y);
 
+  /***en If nonzero, show the cursor according to \<cursor_width\>.  */
+  /***ja ゼロでなければ \<cursor_width\> にしたがってカーソルを表示する。 */
   int with_cursor;
 
   /***en Specifies the character position to display a cursor.  If it
@@ -650,9 +659,9 @@ typedef struct
       displayed next to the last character of an M-text.  If the value
       is negative, even if \<cursor_width\> is nonzero, cursor is not
       displayed.  */
-  /***ja ɽʸ֤򼨤ʸ֤礭С 
-      M-text κǸʸ٤ɽ롣ʤС
-      \<cursor_width\>  0 ǤʤƤ⥫ɽʤ
+  /***ja カーソルを表示する文字位置を示す。最大の文字位置より大きければ、カーソルは 
+      M-text の最後の文字の隣に表示される。負ならば、
+      \<cursor_width\> が 0 でなくてもカーソルは表示されない。
         */
   int cursor_pos;
 
@@ -660,18 +669,18 @@ typedef struct
       \<cursor_pos\>.  If the value is positive, it is the pixel width
       of the cursor.  If the value is negative, the cursor width is
       the same as the underlining glyph(s).  */
-  /***ja 0 ǤʤС\<cursor_pos\> ˥ɽ롣
-      ͤʤСϤ͡ʥԥñ̡ˤǤ롣
-      ʤСΤ륰դƱǤ롣  */
+  /***ja 0 でなければ、\<cursor_pos\> にカーソルを表示する。
+      値が正ならば、カーソルの幅はその値（ピクセル単位）である。
+      負ならば、カーソルのあるグリフと同じ幅である。  */
   int cursor_width;
 
   /***en If nonzero and \<cursor_width\> is also nonzero, display double
       bar cursors; at the character position \<cursor_pos\> and at the
       logically previous character.  Both cursors have one pixel width
       with horizontal fringes at upper or lower positions.  */
-  /***ja If 0 Ǥʤ \<cursor_width\>  0 ǤʤССʸ
-      \<cursor_pos\> ŪˤˤʸΣɽ롣
-      Ȥ⣱ԥǡ夫˿ʿξ꤬Ĥ*/
+  /***ja If 0 でなく、かつ \<cursor_width\> も 0 でなければ、バーカーソルを文字位置
+      \<cursor_pos\> と論理的にそれの前にある文字の２ヶ所に表示する。
+      双方とも１ピクセル幅で、上か下に水平の飾りがつく。*/
   int cursor_bidi;
 
   /***en If nonzero, on drawing partial text, pixels of surrounding
@@ -683,22 +692,23 @@ typedef struct
       right half of V is erased if this member is zero.  By setting
       this member to nonzero, even with such a drawing, we can keep
       this CVC sequence correctly displayed.  */
-  /***ja 0 ǤʤСƥȤΰʬɽݤˡΥƥȤΤɽΰ˿ʬɽ롣
-      ȤСƥ Ҳ-첻-Ҳ 
-      Ȥ󥹤ΤĤϡ첻ĤλҲδ֤˾ˤΤ褦롣
-      Τ褦ʥ󥹤ǤƤꡢǸλҲľ
-      ʤȤС֤򹹿ݤʤɡˤΥФ 0 
-      ǤС첻αȾʬäƤޤ 0 ʳˤ뤳ȤˤäơΤ褦ʺݤˤ
-      Ҳ-첻-Ҳ Υ󥹤ɽ³뤳ȤǤ롣  */
+  /***ja 0 でなければ、テキストの一部分を表示する際に、前後のテキストのうちその表示領域に侵入する部分も表示する。
+      たとえば、タイ語テキスト 子音-母音-子音 
+      というシークエンスのいくつかは、母音が二つの子音の間に上にのるように描かれる。
+      このようなシークエンスがすでに描かれており、最後の子音だけを描き直す場合
+      （たとえば、カーソル位置を更新する際など）このメンバが 0 
+      であれば、母音の右半分が消されてしまう。これを 0 以外にすることによって、そのような際にも
+      子音-母音-子音 のシークエンスを正しく表示し続けることができる。  */
   int partial_update;
 
   /***en If nonzero, don't cache the result of any drawing information
       of an M-text.  */
-  /***ja 0 ǤʤСM-text ɽ˴ؤ򥭥å夷ʤ
+  /***ja 0 でなければ、M-text の表示に関する情報をキャッシュしない。
        */
   int disable_caching;
 
-  /* If non-NULL, limit the drawing effect to the specified region.  */
+  /***en If non-NULL, limit the drawing effect to the specified region.  */
+  /***ja NULL でなければ表示エリアを指定された領域に限定する。 */
   MDrawRegion clip_region;
 
 } MDrawControl;
@@ -715,14 +725,20 @@ extern int mdraw_line_break_option;
     It is also used to represent a rectangle area of a graphic
     device.  */
 /***ja
-    @brief դȥƥȤˡη.
+    @brief グリフとテキストの寸法の型宣言.
 
-    #MDrawMetric ϥդɽ줿ƥȤˡѤηǤ롣
-    ޤɽǥХζΰɽΤˤѤ롣 */
+    #MDrawMetric はグリフと表示されたテキストの寸法用の型である。
+    また、表示デバイスの矩形領域を表すのにも用いられる。 */
 
 typedef struct {
-  int x, y;
-  unsigned int width, height;
+  /*** X coordinates of a glyph or a text.  */
+  int x;
+  /*** Y coordinates of a glyph or a text.  */
+  int y;
+  /*** Pixel width of a glyph or a text.  */
+  unsigned int width;
+  /*** Pixel height of a glyph or a text.  */
+  unsigned int height;
 } MDrawMetric;
 
 /*=*/
@@ -734,53 +750,78 @@ typedef struct {
     The type #MDrawGlyphInfo is the structure that contains
     information about a glyph.  It is used by mdraw_glyph_info ().  */
 /***ja
-    @brief դ˴ؤη.
+    @brief グリフに関する情報の型宣言.
 
-    #MDrawGlyphInfo ϥդ˴ؤޤ๽¤ΤǤ롣
-    mdraw_glyph_info () ϤѤ롣  */
+    #MDrawGlyphInfo 型はグリフに関する情報を含む構造体である。
+    mdraw_glyph_info () はこれを用いる。  */
 
 typedef struct
 {
-  /***en Character range corresponding to the glyph.  */
-  /***ja դбʸϰ.  */
-  int from, to;
+  /***en Start position of character range corresponding to the glyph.  */
+  /***ja グリフに対応する文字の範囲の開始位置.  */
+  int from;
 
-  /***en Character ranges corresponding to the line of the glyph.  */
-  /***ja  դбʸϰ.  */
-  int line_from, line_to;
+  /***en End position of character range corresponding to the glyph.  */
+  /***ja グリフに対応する文字の範囲の終了位置.  */
+  int to;
 
-  /***en X/Y coordinates of the glyph.  */
-  /***ja դ X/Y ɸ.  */
-  int x, y;
+  /***en Start position of character range corresponding to the line of the glyph.  */
+  /***ja 一行のグリフの列に対応する文字の範囲の開始位置.  */
+  int line_from;
+  /***en End position of character range corresponding to the line of the glyph.  */
+  /***ja 一行のグリフの列に対応する文字の範囲の終了位置.  */
+  int line_to;
+
+  /***en X coordinates of the glyph.  */
+  /***ja グリフの X 座標.  */
+  int x;
+  /***en Y coordinates of the glyph.  */
+  /***ja グリフの Y 座標.  */
+  int y;
 
   /***en Metric of the glyph.  */
-  /***ja դˡ.  */
+  /***ja グリフの寸法.  */
   MDrawMetric metrics;
 
   /***en Font used for the glyph.  Set to NULL if no font is found for
       the glyph.  */
-  /***ja դ˻ȤեȡĤʤ NULL */
+  /***ja グリフに使われるフォント。見つからなければ NULL。 */
       
   MFont *font;
 
-  /***en Character ranges corresponding to logically previous and next
-      glyphs.  Note that we do not need the members prev_to and
-      next_from because they must be the same as the members from and
-      to respectively.  */
-  /***ja ŪΥդбʸϰϡ prev_to 
-      next_from ϡ줾 from  to ƱǤϤʤΤ
-      פǤ롣  */
-  int prev_from, next_to;
+  /***en Character ranges corresponding to logically previous glyphs.
+      Note that we do not need the members prev_to because it must
+      be the same as the member \<from\>.  */
+  /***ja 論理的な前のグリフに対応する文字の範囲。メンバ prev_to は、メ
+      ンバ from と同じであるはずなので不要である。  */
+  int prev_from;
+  /***en Character ranges corresponding to logically next glyphs.
+      Note that we do not need the members next_from because it must
+      be the same as the member \<to\> respectively.  */
+  /***ja 論理的な後のグリフに対応する文字の範囲。メンバ next_from は
+      メンバ to と同じであるはずなので不要である。  */
+  int next_to;
 
-  /***en Character ranges corresponding to visually left and right
-      glyphs. */
-  /***ja ɽκΥդбʸϰϡ  */
-  int left_from, left_to;
-  int right_from, right_to;
+  /***en Start position of character ranges corresponding to visually
+      left glyphs. */
+  /***ja 表示上の左のグリフに対応する文字の範囲の開始位置。  */
+  int left_from;
+  /***en End position of character ranges corresponding to visually
+      left glyphs. */
+  /***ja 表示上の左のグリフに対応する文字の範囲の終了位置。  */
+  int left_to;
+  /***en Start position of character ranges corresponding to visually
+      right glyphs. */
+  /***ja 表示上の右のグリフに対応する文字の範囲の開始位置。  */
+  int right_from;
+  /***en End position of character ranges corresponding to visually
+      left glyphs. */
+  /***ja 表示上の右のグリフに対応する文字の範囲の終了位置。  */
+  int right_to;
 
   /***en Logical width of the glyph.  Nominal distance to the next
       glyph.  */
-  /***ja դŪΥդȤܾ̾εΥ  */
+  /***ja グリフの論理的幅。次のグリフとの名目上の距離。  */
   int logical_width;
 } MDrawGlyphInfo;
 
@@ -794,50 +835,68 @@ typedef struct
     about a glyph metric and font.  It is used by the function
     mdraw_glyph_list ().  */
 /***ja
-    @brief դˡȥեȤ˴ؤη.
+    @brief グリフの寸法とフォントに関する情報の型宣言.
 
-    #MDrawGlyph ϥդˡȥեȤ˴ؤޤ๽¤ΤǤ롣
-    mdraw_glyph_list () ϤѤ롣  */
+    #MDrawGlyph 型はグリフの寸法とフォントに関する情報を含む構造体である。
+    mdraw_glyph_list () はこれを用いる。  */
 
 typedef struct
 {
+  /* @{ */
   /***en Character range corresponding to the glyph.  */
-  /***ja դбʸϰ.  */
+  /***ja グリフに対応する文字の範囲.  */
   int from, to;
+  /* @} */
 
   /***en Font glyph code of the glyph.  */
-  /***ja եΥեɡ  */
+  /***ja フォント内のグリフコード。  */
   int glyph_code;
 
   /***en Logical width of the glyph.  Nominal distance to the next
       glyph.  */
-  /***ja դŪΥդȤܾ̾εΥ  */
-  int x_advance, y_advance;
+  /***ja グリフの論理的幅。次のグリフとの名目上の距離。  */
+  int x_advance;
+  /***en Logical height of the glyph.  Nominal distance to the next
+      glyph.  */
+  /***ja グリフの論理的高さ。次のグリフとの名目上の距離。  */
+  int y_advance;
 
-  /***en X/Y offset relative to the glyph position.  */
-  /***ja դΰ֤Ф X/Y եå.  */
-  int x_off, y_off;
+  /***en X offset relative to the glyph position.  */
+  /***ja グリフの位置に対する X オフセット.  */
+  int x_off;
+  /***en Y offset relative to the glyph position.  */
+  /***ja グリフの位置に対する Y オフセット.  */
+  int y_off;
 
-  /***en Metric of the glyph.  */
-  /***ja դˡ.  */
-  int lbearing, rbearing, ascent, descent;
+  /***en Metric of the glyph (left-bearing).  */
+  /***ja グリフの寸法 (left-bearing).  */
+  int lbearing;
+  /***en Metric of the glyph (right-bearing).  */
+  /***ja グリフの寸法 (right-bearing).  */
+  int rbearing;
+  /***en Metric of the glyph (ascent).  */
+  /***ja グリフの寸法 (ascent).  */
+  int ascent;
+  /***en Metric of the glyph (descent).  */
+  /***ja グリフの寸法 (descent).  */
+  int descent;
 
   /***en Font used for the glyph.  Set to NULL if no font is found for
       the glyph.  */
-  /***ja դ˻ȤեȡĤʤ NULL  */
+  /***ja グリフに使われるフォント。見つからなければ NULL。  */
   MFont *font;
 
   /***en Type of the font.  One of Mx, Mfreetype, Mxft.  */
-  /***ja եȤΥסMxMfreetypeMxft Τ줫  */
+  /***ja フォントのタイプ。Mx、Mfreetype、Mxft のいずれか。  */
   MSymbol font_type;
 
   /***en Pointer to the font structure.  The actual type is
       (XFontStruct *) if \<font_type\> member is Mx, FT_Face if
       \<font_type\> member is Mfreetype, and (XftFont *) if \<font_type\>
       member is Mxft.  */
-  /***ja եȤι¤ΤؤΥݥ󥿡ºݤη \<font_type\> Ф
-      Mx ʤ (XFontStruct *) Mfreetype ʤ FT_FaceMxft 
-      ʤ (XftFont *) */
+  /***ja フォントの構造体へのポインタ。実際の型は \<font_type\> メンバが
+      Mx なら (XFontStruct *)、 Mfreetype なら FT_Face、Mxft 
+      なら (XftFont *)。 */
   void *fontp;
 
 } MDrawGlyph;
@@ -852,10 +911,10 @@ typedef struct
     control the drawing of the M-text.  */
 
 /***ja
-    @brief textitem η.
+    @brief textitem の型宣言.
 
-    #MDrawTextItem  @e ƥȥƥ ֥ѤηǤ롣
-    ƥƥȥƥϡ 1 Ĥ M-text ȡɽ椹뤿ξޤǤ롣
+    #MDrawTextItem は @e テキストアイテム オブジェクト用の型である。
+    各テキストアイテムは、 1 個の M-text と、その表示を制御するための情報を含んでいる。
 
     @latexonly \IPAlabel{MTextItem} @endlatexonly  */
 
@@ -867,20 +926,20 @@ typedef struct
 
   /***en Optional change in the position (in the unit of pixel) along
       the X-axis before the M-text is drawn.  */
-  /***ja M-text ɽ˹ԤʤXΰĴ (ԥñ) */
+  /***ja M-text 表示前に行なうX軸方向の位置調整 (ピクセル単位) */
   int delta;                     
 
   /***en Pointer to a face object.  Each property of the face, if not
       Mnil, overrides the same property of face(s) specified as a text
       property in \<mt\>.  */
-  /***ja ե֥ȤؤΥݥ󥿡եγƥץѥƥ 
-      Mnil Ǥʤ \<mt\> ǻꤵ줿եƱץѥƥͥ褹*/
+  /***ja フェースオブジェクトへのポインタ。フェースの各プロパティは 
+      Mnil でなければ \<mt\> で指定されたフェースの同じプロパティに優先する*/
   MFace *face;
 
   /***en Pointer to a draw control object.  The M-text \<mt\> is drawn
       by mdraw_text_with_control () with this control object.  */
-  /***ja ɽ楪֥ȤؤΥݥ󥿡 mdraw_text_with_control () 
-      ϤΥ֥ȤѤ M-text \<mt\> ɽ롣  */
+  /***ja 表示制御オブジェクトへのポインタ。 mdraw_text_with_control () 
+      はこのオブジェクトを用いて M-text \<mt\> を表示する。  */
   MDrawControl *control;
 
 } MDrawTextItem;
@@ -942,7 +1001,7 @@ extern void mdraw_clear_cache (MText *mt);
 
 /*** @ingroup m17nGUI */
 /***en @defgroup m17nInputMethodWin Input Method (GUI) */
-/***ja @defgroup m17nInputMethodWin ϥ᥽å (GUI) */
+/***ja @defgroup m17nInputMethodWin 入力メソッド (GUI) */
 /*=*/
 
 extern MInputDriver minput_gui_driver;
@@ -957,23 +1016,23 @@ extern MInputDriver minput_gui_driver;
     input method.  */
 
 /***ja
-    @brief ؿ minput_create_ic () ΰη.
+    @brief 関数 minput_create_ic () の引数の型宣言.
 
-    #MInputGUIArgIC ϡؿ minput_create_ic () 
-    ϥ᥽åɤϥƥȤݤΡ $ARG ѤηǤ롣  */
+    #MInputGUIArgIC は、関数 minput_create_ic () 
+    が内部入力メソッドの入力コンテクストを生成する際の、引数 $ARG 用の型である。  */
 
 typedef struct
 {
   /***en Frame of the client.  */
-  /***ja 饤ȤΥե졼  */
+  /***ja クライアントのフレーム  */
   MFrame *frame;
 
   /***en Window on which to display the preedit and status text.  */
-  /***ja preedit ƥȤ status ƥȤɽ륦ɥ  */
+  /***ja preedit テキストと status テキストを表示するウィンドウ  */
   MDrawWindow client;
 
   /***en Window that the input context has a focus on.  */
-  /***ja ϥƥȤե򤪤Ƥ륦ɥ  */
+  /***ja 入力コンテクストがフォーカスをおいているウィンドウ  */
   MDrawWindow focus;
 } MInputGUIArgIC;
 
@@ -996,6 +1055,6 @@ M17N_END_HEADER
 
 /*
   Local Variables:
-  coding: euc-japan
+  coding: utf-8
   End:
 */
